from myautoresizer import print_rect, config_logging_default, auto_resize


def ma_printrect():
    config_logging_default()
    print_rect()


def ma_autoresize():
    config_logging_default()
    auto_resize()
